FFI bindings and safe wrapper for libversion, an advanced version string comparison library.
Raw FFI
The ffi module exposes the raw C functions and constants directly.
Safe API
compare and compare_with_flags provide safe Rust wrappers that return
std::cmp::Ordering.
Re-exports
pub use ffi::LIBVERSION_VERSION_MAJOR;pub use ffi::LIBVERSION_VERSION_MINOR;pub use ffi::LIBVERSION_VERSION_PATCH;pub use ffi::VERSIONFLAG_ANY_IS_PATCH;pub use ffi::VERSIONFLAG_LOWER_BOUND;pub use ffi::VERSIONFLAG_P_IS_PATCH;pub use ffi::VERSIONFLAG_UPPER_BOUND;pub use ffi::version_compare2;pub use ffi::version_compare4;
Modules
- ffi
- Raw FFI bindings generated by bindgen.
Functions
- compare
- Compare two version strings.
- compare_
with_ flags - Compare two version strings with per-version flags.
- version_
atleast - Rust equivalent of the
LIBVERSION_VERSION_ATLEASTmacro. - version_
string - Returns the libversion release string from the headers used during build.